%global momorel 3

Summary: DHCPv6 - DHCP server and client for IPv6
Name:    dhcpv6
Version: 1.0.14
Release: %{momorel}m%{?dist}
License: GPL 
Group:   System Environment/Daemons
URL:     https://fedorahosted.org/dhcpv6/
Source0: http://dcantrel.fedorapeople.org/dhcpv6/dhcpv6-%{version}.tar.gz
NoSource: 0

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Prereq: chkconfig, initscripts
BuildRequires: flex, bison, openssl-devel, autoconf, automake, libtool

%description
Implements the Dynamic Host Configuration Protocol (DHCP) for 
Internet Protocol version 6 (IPv6) networks in accordance with 
RFC 3315 : Dynamic Host Configuration Protocol for IPv6 (DHCPv6).
Consists of dhcp6s(8), the server DHCP daemon, and dhcp6r(8),
the DHCPv6 relay agent. 
Install this if you want to support dynamic configuration of
IPv6 addresses and parameters on your IPv6 network.
See man dhcp6s(8), dhcp6r(8), dhcp6s.conf(5),
and the documentation in /usr/share/doc/dhcpv6* .

%package -n dhcpv6-client
Summary:  DHCPv6 client
Requires: initscripts >= 7.73
Group: System Environment/Base
Obsoletes: dhcpv6_client

%description -n dhcpv6-client
Provides the client for the DHCPv6 protocol (RFC 3315) to support dynamic
configuration of IPv6 addresses and parameters.
 
%package -n libdhcp6client
Summary: The DHCPv6 client in a library for invocation by other programs
Group:  Development/Libraries
 
%description -n libdhcp6client
Provides the client for the DHCPv6 protocol (RFC 3315) to support dynamic
configuration of IPv6 addresses and parameters, in a library for invocation
by other programs.

%package -n libdhcp6client-devel
Summary:  Header files for development with the DHCPv6 client library
Group:    Development/Libraries
Requires: pkgconfig
Requires: libdhcp6client = %{version}-%{release}
  
%description -n libdhcp6client-devel
Header files for development with the DHCPv6 client library.
  
%package -n libdhcp6client-static
Summary:  Static archive for libdhcp6client
Group:    Development/Libraries
Requires: libdhcp6client-devel = %{version}-%{release}
 
%description -n libdhcp6client-static
The libdhcp6client-static package contains the static archive for
libdhcp6client.

%prep
%setup -q
 
%build
%configure
%make

%install
rm -rf $RPM_BUILD_ROOT

rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
 
rm -rf %{buildroot}%{_libdir}/libdhcp6client.la
 
mkdir -p %{buildroot}/sbin
mv %{buildroot}%{_sbindir}/dhcp6c %{buildroot}/sbin/dhcp6c
mv %{buildroot}%{_sysconfdir}/rc.d/init.d  %{buildroot}%{_sysconfdir}/init.d

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}

%post
/sbin/chkconfig --add dhcp6s
/sbin/chkconfig --add dhcp6r || :

%preun
if [ $1 = 0 ]; then
    /sbin/service dhcp6s status > /dev/null 2>&1
    if [ $? = 3 ]; then
        /sbin/service dhcp6s stop > /dev/null 2>&1
    fi

    /sbin/service dhcp6r status > /dev/null 2>&1
    if [ $? = 3 ]; then
        /sbin/service dhcp6r stop > /dev/null 2>&1
    fi

    /sbin/chkconfig --del dhcp6s
    /sbin/chkconfig --del dhcp6r || :

fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service dhcp6s condrestart >/dev/null 2>&1
    /sbin/service dhcp6r condrestart >/dev/null 2>&1 || :
fi
exit 0

%post -n libdhcp6client -p /sbin/ldconfig

%postun -n libdhcp6client -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%attr(754,root,root) %{_sbindir}/dhcp6s
%attr(754,root,root) %{_sbindir}/dhcp6r
%attr(755,root,root) %config /etc/init.d/dhcp6s
%attr(755,root,root) %config /etc/init.d/dhcp6r
%config(noreplace) /etc/sysconfig/dhcp6s
%config(noreplace) /etc/sysconfig/dhcp6r
%attr(644,root,root) %config /etc//dhcp6s.conf
%{_mandir}/man8/dhcp6s.8.*
%{_mandir}/man5/dhcp6s.conf.5.*
%{_mandir}/man8/dhcp6r.8.*
%doc docs/* README

%files -n dhcpv6-client
%defattr(-,root,root,-)
%attr(750,root,root) /sbin/dhcp6c
%attr(644,root,root) %config /etc/dhcp6c.conf
%{_mandir}/man8/dhcp6c.8.*
%{_mandir}/man5/dhcp6c.conf.5.*
%doc README 
%attr(750,root,root) %dir %{_localstatedir}/lib/dhcpv6

%files -n libdhcp6client
%defattr(-,root,root,-)
%{_libdir}/libdhcp6client-1.0.so.*

%files -n libdhcp6client-devel
%defattr(0644,root,root,0755)
%{_includedir}/*
%{_libdir}/pkgconfig/libdhcp6client.pc
%defattr(-,root,root,-)
%{_libdir}/libdhcp6client.so

%files -n libdhcp6client-static
%defattr(0644,root,root,0755)
%{_libdir}/libdhcp6client.a

%changelog
* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (1.0.14-3m)
- rebuild against rpm-4.6

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.0.14-2m)
- rebuild against gcc43

* Thu Mar 27 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.14-1m)
- update 1.0.14

* Mon Mar  3 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.12-2m)
- symbol was not found...
-- dhcpv6-1.0.12-visibility.patch

* Sun Mar  2 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.12-1m)
- update 1.0.12

* Wed Feb  6 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.11-1m)
- update 1.0.11

* Mon Jan 28 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.10-1m)
- update 1.0.10

* Fri Jan 11 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.4-1m)
- update 1.0.4

* Fri Jan 11 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (1.0.2-1m)
- update 1.0.2

* Tue Feb 20 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-7m)
- sync fc-devel (0.10-40)

* Wed Jan 24 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-6m)
- sync fc-devel (0.10-35)

* Sun Jul  2 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-5m)
- sync fc-devel

* Sat Jun 24 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-4m)
- sync fc-devel

* Sat Jun 10 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.10-3m)
- delete duplicate dir

* Fri Jun  9 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.10-2m)
- delete duplicate dirs %%dir %%{_localstatedir}/lib/dhcpv6
- re-add %%dir %%{_localstatedir}/lib/dhcpv6
  because dhcpv6 pkg is not required by dhcpv6_clinets pkg

* Thu Jun  8 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.10-1m)
- import from FC5

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 0.10-16.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-16
- rebuild for new gcc, glibc, glibc-kernheaders

* Sun Dec 18 2005 Jason Vas Dias<jvdias@redhat.com> - 0.10-15.2
- rebuild for new gcc & flex

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov  9 2005 Tomas Mraz <tmraz@redhat.com> - 0.10-15
- rebuilt with new openssl

* Mon Aug 15 2005 Jason Vas Dias <jvdias@redhat.com>
- fix bug 165882: allow client to configure an interface which
  does not have an IPv4 address ( use getifaddrs instead of
  ioctl(sockfd, SIOGIFCONF, ...)
- fix bug 165884 (possibly!): force use of glibc's getifaddrs,
  not internal getifaddrs implementation

* Fri Apr 01 2005 Florian La Roche <laroche@redhat.com>
- made perms for /var/lib/dhcpv6 the same

* Fri Mar 25 2005 Florian La Roche <laroche@redhat.com>
- add "exit 0" to postun script

* Thu Jan 13 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Fix misc. compiler warnings and ms-dos formatted man-pages

* Wed Jan 12 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Add 'prefix-delegation-interface' option to allow write
- of radvd interface configuration other than that for 
- the interface the lease was received on.

* Mon Jan 10 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Fix bug 144585: dhcp6c wasn't writing radvd.conf in prefix delegation mode

* Sun Jan 9  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Add Relay Agent support. Thanks to  Brian Bluesker<bbuesker@qualcomm.com>
- for the patch to add relay support to the server and for submitting the 
- patch originally contributed by Cristian Cadar of NEC Europe to 
- DHCPv6-developer  mailing list.

* Fri Jan 7  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-9
- fix bug 143728: SEGV core on resolv.conf + radvd.conf update -
- yywrap()'s must return 1

* Mon Oct 18 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-7
- fix bug 136146: clean up code - prevent compiler warnings

* Mon Sep 13 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-6
- fix bug 132468 for bug 125712: invoke change_resolv_conf

* Mon Sep 13 2004 Bill Nottingham <notting@redhat.com> - 0.10-5
- don't run by default
- add chkconfig prereqs, postun script, etc.

* Thu Sep  2 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-3/4
- fixed missing %defattr for dhcpv6_client - bug 131638

* Mon Aug 30 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-2
- Split into two packages: dhcpv6-*, containing server only,
- and dhcpv6_client-*, containing client only.

* Thu Aug 26 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-1 
- Initial build.

